<?php


namespace Elementor;

use \Elementor\Controls_Manager;


if (!defined('ABSPATH')) exit;

class Master_Site_Logo extends Widget_Base

{

    public $base;


    public function __construct($data = [], $args = null)

    {

        parent::__construct($data, $args);


        wp_register_style('master-logo-css', \MasterElements::widgets_url() . '/site-logo/assets/css/master-logo.css', false, \MasterElements::version);


    }

    public function get_style_depends()
    {


        return ['master-logo-css'];

    }


    public function get_name()

    {

        /////////////////////////////////////

        //get name of file

        /////////////////////////////////////

        return 'master-logo';

    }


    public function get_title()

    {

        /////////////////////////////////////

        //get title from file

        /////////////////////////////////////

        return esc_html__('Master Logo', 'masterelements');

    }


    public function get_icon()

    {

        /////////////////////////////////////

        //get icon

        /////////////////////////////////////

        return 'eicon-site-logo';

    }


    public function get_categories()

    {

        //////////////////////////////////////////////////////////////////////////

        //get category where widget will be added in elementor front end

        //////////////////////////////////////////////////////////////////////////

        return ['master-addons'];

    }

//////////////////////////////////////////////////////////////////////////

// elementor default function to register your controls

//////////////////////////////////////////////////////////////////////////

    protected function _register_controls()

    {

        /////////////////////////////////////

//  Content Section Start

/////////////////////////////////////

        $this->start_controls_section(

        ////////////////////////////////////////////////////////////////////////////////////////////

        //section which is shown after you drage your widget in the fornt-end area

        ////////////////////////////////////////////////////////////////////////////////////////////


            'section_content',

            [

                'label' => __('Master Logo', 'additional-addons'),//......

            ]

        );


//////////////////////////////////////////////////////////

// add Image//////////////////////////////////////////////

/////////////////////////////////////////////////////////

        $this->add_control(

            'image',

            [

                'label' => __('Choose Image', 'masterelements'),

                'type' => Controls_Manager::MEDIA,

                'dynamic' => [

                    'active' => true,

                ],


                'default' => [

                    'url' => Utils::get_placeholder_image_src(),

                ],

            ]

        );

        $this->add_group_control(

            Group_Control_Image_Size::get_type(),

            [

                'name' => 'image',

                'default' => 'large',

            ]

        );

        $this->add_control(

            'site_logo_image_align',

            [

                'label' => __('Image Alignment', 'masterelements'),

                'type' => \Elementor\Controls_Manager::CHOOSE,

                'options' => [

                    'left' => [

                        'title' => __('Left', 'masterelements'),

                        'icon' => 'fa fa-align-left',

                    ],

                    'center' => [

                        'title' => __('Center', 'masterelements'),

                        'icon' => 'fa fa-align-center',

                    ],

                    'right' => [

                        'title' => __('Right', 'masterelements'),

                        'icon' => 'fa fa-align-right',

                    ],

                ],

                'default' => 'center',

                'toggle' => true,

                'selectors' => [

                    '{{WRAPPER}} .master-logo' => 'text-align: {{VALUE}};',

                ],

            ]

        );

        $this->add_control(

            'site_logo_caption_source',

            [

                'label' => __('Caption', 'Masterelements'),

                'type' => Controls_Manager::SELECT,

                'options' => [

                    'none' => __('None', 'masterelements'),

                    'attachment' => __('Attachment Caption', 'masterelements'),

                    'custom' => __('Custom Caption', 'masterelements'),

                ],

                'default' => 'none',

            ]

        );


        $this->add_control(

            'site_logo_caption',

            [

                'label' => __('Custom Caption', 'masterelements'),

                'type' => Controls_Manager::TEXT,

                'default' => '',

                'placeholder' => __('Enter your image caption', 'masterelements'),

                'condition' => [

                    'site_logo_caption_source' => 'custom',

                ],

                'dynamic' => [

                    'active' => true,

                ],

            ]

        );


        $this->add_control(

            'site_logo_display_link',

            [

                'label' => __('Custom Link', 'masterelements'),

                'type' => \Elementor\Controls_Manager::SWITCHER,

                'label_on' => __('Show', 'masterelements'),

                'label_off' => __('Hide', 'masterelements'),

                'return_value' => 'yes',

                'default' => 'empty',

            ]

        );


        $this->add_control(

            'site_logo_link',

            [

                'label' => __('Link', 'masterelements'),

                'type' => \Elementor\Controls_Manager::URL,

                'placeholder' => __('https://your-link.com', 'masterelements'),

                'show_external' => true,

                'default' => [

                    'url' => '',

                    'is_external' => true,

                    'nofollow' => true,

                ],

                'condition' => [

                    'site_logo_display_link' => 'yes'

                ],

            ]

        );


        $this->end_controls_section();


        $this->start_controls_section(

            'section_style',

            [

                'label' => __('Style', 'masterelements'),

                'tab' => Controls_Manager::TAB_STYLE,

            ]


        );

        $this->add_responsive_control(

            'site_logo_width',

            [

                'label' => __('Width', 'masterelements'),

                'type' => Controls_Manager::SLIDER,

                'size_units' => ['px', '%', 'vw'],

                'default' => [

                    'unit' => '%',

                    'size' => 50,

                ],

                'selectors' => [

                    '{{WRAPPER}} .master-logo img' => 'width: {{SIZE}}{{UNIT}};',

                ],

            ]

        );

        $this->add_control(

            'site_logo_max_width',

            [

                'label' => __('Max Width(%)', 'masterelements'),

                'type' => Controls_Manager::SLIDER,

                'size_units' => ['%'],

                'range' => [


                    '%' => [

                        'min' => 0,

                        'max' => 100,

                    ],

                ],

                'default' => [

                    'unit' => '%',

                    'size' => 50,

                ],

                'selectors' => [

                    '{{WRAPPER}}  .master-logo img' => 'max-width: {{SIZE}}{{UNIT}};',

                ],

            ]

        );

        $this->add_responsive_control(

            'site_logo_opacity',

            [

                'label' => __('Opacity', 'masterelements'),

                'type' => Controls_Manager::NUMBER,

                'min' => 0,

                'max' => 1,

                'selectors' => [

                    '{{WRAPPER}} .master-logo ,{{WRAPPER}} .master-image' => 'opacity: {{SIZE}};',

                ],

            ]

        );

        $this->add_control(

            'site_logo_css_filters',

            [

                'label' => __('CSS Filters', 'masterelements'),

                'label_block' => true,

                'type' => Controls_Manager::SELECT,

                'multiple' => true,

                'default' => __('Select Filter', 'masterelements'),

                'options' => [

                    'blur' => __('Blur', 'masterelements'),

                    'brightness' => __('Brightness', 'masterelements'),

                    'contrast' => __('Contrast', 'masterelements'),

                    'saturate' => __('Saturation', 'masterelements'),


                ],

            ]

        );


        $this->add_group_control(

            Group_Control_Border::get_type(),

            [

                'name' => 'master_border',

                'label' => __('Border', 'masterelements'),

                'selector' => '{{WRAPPER}} .master-logo img',

            ]

        );

        $this->add_control(

            'site_logo_border_radius',

            [

                'label' => __('Border Radius', 'masterelements'),

                'type' => Controls_Manager::DIMENSIONS,

                'size_units' => ['px', '%', 'em'],

                'selectors' => [

                    '{{WRAPPER}} .master-logo img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',

                ],

            ]

        );

        $this->add_control(

            'site_logo_hover_animation',

            [

                'label' => __('Hover Animation', 'masterelements'),

                'type' => Controls_Manager::HOVER_ANIMATION,

                'prefix_class' => 'elementor-animation-',

            ]

        );


        $this->end_controls_section();


    }

    private function has_caption($settings)
    {

        return (!empty($settings['site_logo_caption_source']) && 'none' !== $settings['site_logo_caption_source']);

    }

    private function get_caption($settings)
    {

        $caption = '';

        if (!empty($settings['site_logo_caption_source'])) {

            switch ($settings['site_logo_caption_source']) {

                case 'attachment':

                    $caption = wp_get_attachment_caption($settings['image']['id']);

                    break;

                case 'custom':

                    $caption = !Utils::is_empty($settings['site_logo_caption']) ? $settings['site_logo_caption'] : '';

            }

        }

        return $caption;

    }

//function to show how front end will look like after you change settings in Logo widget

//front end live preview.

    protected function render()

    {

        $settings = $this->get_settings_for_display();

        $has_caption = $this->has_caption($settings);

        ?>

        <?php $target = $settings['site_logo_link']['is_external'] ? ' target="_blank"' : ''; ?>

        <?php $nofollow = $settings['site_logo_link']['nofollow'] ? ' rel="nofollow"' : ''; ?>

        <?php

        if ($settings['site_logo_display_link'] == 'yes') {

            $url = $settings['site_logo_link']['url'];

        } else {

            $url = home_url('/');

        }

        ?>

        <div class="master-logo filter-<?= $settings['site_logo_css_filters'] ?>">

            <?php if ($has_caption) : ?>

            <figure>

                <?php endif; ?>

                <a class="master-link" href="<?= $url ?>" <?= $target . ' ' . $nofollow; ?>>

                    <?php echo Group_Control_Image_Size::get_attachment_image_html($settings); ?></a>

                <?php if ($has_caption) : ?>

                    <figcaption
                            class="widget-image-caption wp-caption-text"><?php echo $this->get_caption($settings); ?></figcaption>

                <?php endif; ?>

                <?php if ($has_caption) : ?>

            </figure>

        <?php endif; ?>

        </div>

        <?php

    }

}

