<?php

namespace Elementor;

use MasterElements\Master_Woocommerce_Functions;

if (!defined('ABSPATH')) exit; // Exit if accessed directly

class Master_Woo_Product_Rating extends Widget_Base
{

    public function __construct($data = [], $args = null)
    {

        parent::__construct($data, $args);
        wp_register_style('me-woo-product-rating-css', \MasterElements::widgets_url() . '/woo-product-rating/css/woo-product-rating.css', false, \MasterElements::version);
    }

    public function get_style_depends()
    {
        return ['me-woo-product-rating-css'];
    }

    public function get_name()
    {
        return 'woo-product-rating';
    }

    public function get_title()
    {
        return __('Woo Product Rating', 'masterelements');
    }

    public function get_categories()
    {
        return array('master-addons');
    }

    public function get_icon()
    {
        return 'eicon-product-rating';
    }


    protected function _register_controls()
    {

        // Product Rating Style
        $this->start_controls_section(
            'me_product_rating_style_section',
            array(
                'label' => __('Style', 'masterelements'),
                'tab' => Controls_Manager::TAB_STYLE,
            )
        );
        $this->add_control(
            'me_product_rating_color',
            [
                'label' => __('Star Color', 'masterelements'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .star-rating' => 'color: {{VALUE}} !important;',
                    '{{WRAPPER}} .me_woocommerce-product-rating' => 'color: {{VALUE}} !important;',
                ],
            ]
        );

        $this->add_responsive_control(
            'me_product_rating_margin',
            [
                'label' => __('Margin', 'masterelements'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} .woocommerce .star-rating' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );


        $this->add_control(
            'me_product_rating_text_color',
            [
                'label' => __('Link Color', 'masterelements'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} a.woocommerce-review-link' => 'color: {{VALUE}} !important;',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            array(
                'name' => 'me_product_rating_link_typography',
                'label' => __('Link Typography', 'masterelements'),
                'selector' => '{{WRAPPER}} a.woocommerce-review-link',
            )
        );

        $this->end_controls_section();

    }

    /**
     * WooCommerce Classes, Actions and Filters Used in this Function
     */
    protected function render()
    {
        $master_product_rating = new Master_Woocommerce_Functions();
        global $product;
        $product = $master_product_rating::mw_wc_get_product();
        $post_type = get_post_type();

        if ('product' == $post_type) {
            $count_rating = $master_product_rating::mw_wc_get_product()->get_rating_count();

            $review = $master_product_rating::mw_wc_get_product()->get_review_count();

            $avg = $master_product_rating::mw_wc_get_product()->get_average_rating();
            ?>

            <div class="product">

                <div class="me_woocommerce-product-rating">

                    <?php echo $master_product_rating::mw_get_rating($avg, $count_rating); ?>

                    <?php if (comments_open()) : ?>

                        <?php //phpcs:disable ?>

                        <a href="#reviews" class="woocommerce-review-link"
                           rel="nofollow">(<?php printf(_n('%s customer review', '%s customer reviews', $review, 'masterelements'), '<span class="count">' . esc_html($review) . '</span>'); ?>
                            )</a>

                        <?php // phpcs:enable ?>

                    <?php endif ?>

                </div>

            </div>

            <?php
        } else {
            echo '<div class="woocommerce single-product"><div class="product">';

            echo '<div class="me_woocommerce-product-rating">
            
            <div class="star-rating"><span style="width:80%">Rated <strong class="rating">4.00</strong> out of 5 based on <span class="rating">1</span> customer rating</span></div>		<a href="#reviews" class="woocommerce-review-link" rel="nofollow">(<span class="count">1</span> customer review)</a>	</div>';

            echo '</div></div>';
        }
    }

}